BinderBuildContextExtensions extension

Public extensions on BuildContext.

on

Methods

read<T>(Watchable<T> watchable) → T

Available on BuildContext, provided by the BinderBuildContextExtensions extension

Reads the current state of the watchable.
use<T>(LogicRef<T> ref) → T

Available on BuildContext, provided by the BinderBuildContextExtensions extension

Gets the instance of the business logic component referenced by ref.
watch<T>(Watchable<T> watchable) → T

Available on BuildContext, provided by the BinderBuildContextExtensions extension

Reads the current state of watchable and rebuilds the widget calling this methods when the state changes.