Computed<T> class

A watchable derived state.

Inheritance
Available extensions

Constructors

Computed(StateBuilder<T> stateBuilder, {EqualityComparer<T>? equalityComparer})
Creates a derived state which combine the current state of other parts and allows any widget to be rebuilt when the underlaying value changes.
const

Properties

equalityComparer → EqualityComparer<T>?
The predicate determining if two states are the same.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateBuilder → StateBuilder<T>
The function used to build the state.
final

Methods

equals(T oldState, T newState) bool
Internal use only.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(StateReader read, List<BinderKey>? keys) → T
Internal use only.
override
select<S>(Selector<T, S> selector, {EqualityComparer<S>? equalityComparer}) Watchable<S>

Available on Watchable<T>, provided by the WatchableExtensions extension

Creates a selector on a reference that can be watched.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited