BinderBuildContextExtensions extension
Public extensions on BuildContext.
- on
Methods
-
read<
T> (Watchable< T> watchable) → T -
Available on BuildContext, provided by the BinderBuildContextExtensions extension
Reads the current state of thewatchable. -
use<
T> (LogicRef< T> ref) → T -
Available on BuildContext, provided by the BinderBuildContextExtensions extension
Gets the instance of the business logic component referenced byref. -
watch<
T> (Watchable< T> watchable) → T -
Available on BuildContext, provided by the BinderBuildContextExtensions extension
Reads the current state ofwatchableand rebuilds the widget calling this methods when the state changes.